#ifndef ACCOUNTSETTINGSTAB_H
#define ACCOUNTSETTINGSTAB_H

#include <QWidget>

class ServiceAccountsModel;
class QTreeView;
class QMenu;

class AccountSettingsTab : public QWidget
{
    Q_OBJECT

public:
    explicit AccountSettingsTab(QWidget *parent = 0);
    ~AccountSettingsTab();

private slots:
    void showContextMenu(const QPoint &pos);
    void removeAccount();
    void editAccount();

private:
    ServiceAccountsModel *m_model;
    QTreeView *m_view;
    QMenu *m_contextMenu;
    QAction *m_editAction;
    QAction *m_removeAction;
};

#endif // ACCOUNTSETTINGSTAB_H
